Learn R Programming

tidypaleo (version 0.1.4)

halifax_lakes_plottable: Halifax lakes water chemistry and top/bottom diatom counts

Description

A subset of well-labeled, clean diatom count data for 44 Halifax-area (Nova Scotia) lakes, an analysis of which has been published by Ginn et al. (2015).

Usage

halifax_lakes_plottable

Arguments

Format

An object of class tbl_df (inherits from tbl, data.frame) with 114 rows and 5 columns.

References

Ginn, Brian K., Thiyake Rajaratnam, Brian F. Cumming, and John P. Smol. "Establishing Realistic Management Objectives for Urban Lakes Using Paleolimnological Techniques: An Example from Halifax Region (Nova Scotia, Canada)." Lake and Reservoir Management 31, no. 2 (April 3, 2015): 92-108. tools:::Rd_expr_doi("10.1080/10402381.2015.1013648").

Examples

Run this code
halifax_lakes_plottable

Run the code above in your browser using DataLab