powered by
Predict age and depth values
# S3 method for age_depth_model predict(object, .data = NULL, depth = NULL, age = NULL, ...)predict_depth(object, age)predict_age(object, depth)
predict_depth(object, age)
predict_age(object, depth)
A data frame with the same number of observations as the input age or depth vector.
An age_depth_model object
Optional input data frame
Specify exactly one of these to predict the other.
Unused
adm <- age_depth_model( alta_lake_210Pb_ages, depth = depth_cm, age = age_year_ad, age_max = age_year_ad + age_error_yr, age_min = age_year_ad - age_error_yr ) predict(adm, depth = 1:5)
Run the code above in your browser using DataLab