Learn R Programming

tidypaleo (version 0.1.4)

rotated_facet_labels: Common plot modifications for stratigraphic plots

Description

Common plot modifications for stratigraphic plots

Usage

rotated_facet_labels(
  angle = 45,
  direction = "x",
  remove_label_background = TRUE
)

rotated_axis_labels(angle = 90, direction = "x")

Value

An object or list of objects that can be added to a ggplot

Arguments

angle

The angle at which labels should be rotated

direction

The axes along which the operations should be performed

remove_label_background

Whether or not label backgrounds should be removed along rotated label axes

Examples

Run this code
library(ggplot2)

ggplot(mpg, aes(cty, hwy)) +
  geom_point() +
  facet_wrap(vars(class)) +
  rotated_facet_labels(45, "x")

Run the code above in your browser using DataLab