as_trans_factory: Coerce and validate transforms and functions that produce them
Description
Coerce and validate transforms and functions that produce them
Usage
as_trans_factory(factory, env = parent.frame())validate_trans_factory(factory, x = 1:3, y = 1:3)
validate_trans(trans, x = 1:3, y = 1:3)
Value
The input, invisibly.
Arguments
- factory
A function that produces a transform object
- env
The calling environment, for transform factories that are calls or
rlang lambda-style functions.
- x
The test x data
- y
The test y data
- trans
A transform object
Examples
Run this codeas_trans_factory(age_depth_interpolate)
Run the code above in your browser using DataLab