powered by
Common plot modifications for stratigraphic plots
rotated_facet_labels( angle = 45, direction = "x", remove_label_background = TRUE )rotated_axis_labels(angle = 90, direction = "x")
rotated_axis_labels(angle = 90, direction = "x")
An object or list of objects that can be added to a ggplot
The angle at which labels should be rotated
The axes along which the operations should be performed
Whether or not label backgrounds should be removed along rotated label axes
library(ggplot2) ggplot(mpg, aes(cty, hwy)) + geom_point() + facet_wrap(vars(class)) + rotated_facet_labels(45, "x")
Run the code above in your browser using DataLab